==> anyunit-0.1.1-py3-none-any.whl: anyunit/units.py <==
LENGTH = {
    "meter": 1.0,
    "kilometer": 1000.0,
    "centimeter": 0.01,
    "millimeter": 0.001,
    "micrometer": 1e-6,
    "nanometer": 1e-9,
    "picometer": 1e-12,
    "angstrom": 1e-10,

    "mile": 1609.344,
    "nautical_mile": 1852.0,
    "yard": 0.9144,
    "foot": 0.3048,
    "inch": 0.0254,
    "mil": 2.54e-5,
    "fathom": 1.8288,

    "astronomical_unit": 149597870700.0,
    "light_year": 9460730472580800.0,
    "parsec": 3.08567758149137e16,
    "light_second": 299792458.0,

    "verst": 1066.8,
    "arshin": 0.7112,
    "furlong": 201.168,
    "league": 4828.03,
    "cubit": 0.4572,
    "span": 0.2286,

    "shaku": 0.30303,
    "ken": 1.81818,
    "ri": 3927.27,

    "chi": 0.3333,
    "zhang": 3.3333,
    "li": 500.0
}

WEIGHT = {
    "kilogram": 1.0,
    "gram": 0.001,
    "milligram": 1e-6,
    "microgram": 1e-9,
    "tonne": 1000.0,
    "carat": 0.0002,

    "pound": 0.45359237,
    "ounce": 0.0283495,
    "stone": 6.35029,
    "short_ton": 907.185,
    "long_ton": 1016.05,

    "troy_ounce": 0.0311035,
    "troy_pound": 0.373242,

    "tael": 0.037799,
    "catty": 0.60479,
    "jin": 0.5,

    "pood": 16.3807,
    "berkovets": 163.805,

    "grain": 6.47989e-5,
    "slug": 14.5939,
    "solar_mass": 1.98847e30
}

AREA = {
    'square_meter': 1.0,
    'square_kilometer': 1000000.0,
    'square_centimeter': 0.0001,
    'square_millimeter': 0.000001,
    'square_foot': 0.092903,
    'square_inch': 0.00064516,
    'square_yard': 0.836127,
    'square_mile': 2589988.11,
    'acre': 4046.86,
    'hectare': 10000.0
}

==> anyunit-0.1.3-py3-none-any.whl: anyunit/units.py <==
LENGTH = {
    "meter": 1.0,
    "kilometer": 1000.0,
    "centimeter": 0.01,
    "millimeter": 0.001,
    "micrometer": 1e-6,
    "nanometer": 1e-9,
    "picometer": 1e-12,
    "angstrom": 1e-10,

    "mile": 1609.344,
    "nautical_mile": 1852.0,
    "yard": 0.9144,
    "foot": 0.3048,
    "inch": 0.0254,
    "mil": 2.54e-5,
    "fathom": 1.8288,

    "astronomical_unit": 149597870700.0,
    "light_year": 9460730472580800.0,
    "parsec": 3.08567758149137e16,
    "light_second": 299792458.0,

    "verst": 1066.8,
    "arshin": 0.7112,
    "furlong": 201.168,
    "league": 4828.03,
    "cubit": 0.4572,
    "span": 0.2286,

    "shaku": 0.30303,
    "ken": 1.81818,
    "ri": 3927.27,

    "chi": 0.3333,
    "zhang": 3.3333,
    "li": 500.0
}

WEIGHT = {
    "kilogram": 1.0,
    "gram": 0.001,
    "milligram": 1e-6,
    "microgram": 1e-9,
    "tonne": 1000.0,
    "carat": 0.0002,

    "pound": 0.45359237,
    "ounce": 0.0283495,
    "stone": 6.35029,
    "short_ton": 907.185,
    "long_ton": 1016.05,

    "troy_ounce": 0.0311035,
    "troy_pound": 0.373242,

    "tael": 0.037799,
    "catty": 0.60479,
    "jin": 0.5,

    "pood": 16.3807,
    "berkovets": 163.805,

    "grain": 6.47989e-5,
    "slug": 14.5939,
    "solar_mass": 1.98847e30
}

AREA = {
    'meter': 1.0,
    'kilometer': 1000000.0,
    'centimeter': 0.0001,
    'millimeter': 0.000001,
    'foot': 0.092903,
    'inch': 0.00064516,
    'yard': 0.836127,
    'mile': 2589988.11,
    'acre': 4046.86,
    'hectare': 10000.0
}
